@@ -20,6 +20,7 @@
 package org.jboss.logmanager;
 
 import java.io.IOException;
+import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.text.MessageFormat;
 import java.util.Map;
@@ -28,6 +29,9 @@ import java.util.ResourceBundle;
 
 import java.util.logging.LogRecord;
 
+import org.wildfly.common.net.HostName;
+import org.wildfly.common.os.Process;
+
 /**
  * An extended log record, which includes additional information including MDC/NDC and correct
  * caller location (even in the presence of a logging facade).
@@ -80,6 +84,9 @@ public class ExtLogRecord extends LogRecord {
         this.loggerClassName = loggerClassName;
         ndc = NDC.get();
         threadName = Thread.currentThread().getName();
+        hostName = HostName.getQualifiedHostName();
+        processName = Process.getProcessName();
+        processId = Process.getProcessId();
     }
 
     /**
@@ -111,6 +118,9 @@ public class ExtLogRecord extends LogRecord {
         threadName = original.threadName;
         resourceKey = original.resourceKey;
         formattedMessage = original.formattedMessage;
+        hostName = original.hostName;
+        processName = original.processName;
+        processId = original.processId;
     }
 
     /**
@@ -141,12 +151,35 @@ public class ExtLogRecord extends LogRecord {
     private String resourceKey;
     private String formattedMessage;
     private String threadName;
+    private String hostName;
+    private String processName;
+    private long processId = -1;
+    private String sourceModuleName;
+    private String sourceModuleVersion;
 
     private void writeObject(ObjectOutputStream oos) throws IOException {
         copyAll();
         oos.defaultWriteObject();
     }
 
+    @SuppressWarnings("unchecked")
+    private void readObject(ObjectInputStream ois) throws IOException, ClassNotFoundException {
+        final ObjectInputStream.GetField fields = ois.readFields();
+        ndc = (String) fields.get("ndc", null);
+        formatStyle = (FormatStyle) fields.get("formatStyle", FormatStyle.MESSAGE_FORMAT);
+        mdcCopy = (FastCopyHashMap<String, Object>) fields.get("mdcCopy", new FastCopyHashMap<>());
+        sourceLineNumber = fields.get("sourceLineNumber", -1);
+        sourceFileName = (String) fields.get("sourceFileName", null);
+        resourceKey = (String) fields.get("resourceKey", null);
+        formattedMessage = (String) fields.get("formattedMessage", null);
+        threadName = (String) fields.get("threadName", null);
+        hostName = (String) fields.get("hostName", null);
+        processName = (String) fields.get("processName", null);
+        processId = fields.get("processId", -1L);
+        sourceModuleName = (String) fields.get("sourceModuleName", null);
+        sourceModuleVersion = (String) fields.get("sourceModuleVersion", null);
+    }
+
     /**
      * Disable caller calculation for this record.  If the caller has already been calculated, leave it; otherwise
      * set the caller to {@code "unknown"}.
@@ -297,30 +330,16 @@ public class ExtLogRecord extends LogRecord {
             return;
         }
         calculateCaller = false;
-        final StackTraceElement[] stack = new Throwable().getStackTrace();
-        boolean found = false;
-        for (StackTraceElement element : stack) {
-            final String className = element.getClassName();
-            if (found) {
-                if (! loggerClassName.equals(className)) {
-                    setSourceClassName(className);
-                    setSourceMethodName(element.getMethodName());
-                    setSourceLineNumber(element.getLineNumber());
-                    setSourceFileName(element.getFileName());
-                    return;
-                }
-            } else {
-                found = loggerClassName.equals(className);
-            }
-        }
-        setUnknownCaller();
+        JDKSpecific.calculateCaller(this);
     }
 
-    private void setUnknownCaller() {
-        setSourceClassName("<unknown>");
-        setSourceMethodName("<unknown>");
+    void setUnknownCaller() {
+        setSourceClassName(null);
+        setSourceMethodName(null);
         setSourceLineNumber(-1);
-        setSourceFileName("<unknown>");
+        setSourceFileName(null);
+        setSourceModuleName(null);
+        setSourceModuleVersion(null);
     }
 
     /**
@@ -397,6 +416,46 @@ public class ExtLogRecord extends LogRecord {
         super.setSourceMethodName(sourceMethodName);
     }
 
+    /**
+     * Get the name of the module that initiated the logging request, if known.
+     *
+     * @return the name of the module that initiated the logging request
+     */
+    public String getSourceModuleName() {
+        calculateCaller();
+        return sourceModuleName;
+    }
+
+    /**
+     * Set the source module name of this record.
+     *
+     * @param sourceModuleName the source module name
+     */
+    public void setSourceModuleName(final String sourceModuleName) {
+        calculateCaller = false;
+        this.sourceModuleName = sourceModuleName;
+    }
+
+    /**
+     * Get the version of the module that initiated the logging request, if known.
+     *
+     * @return the version of the module that initiated the logging request
+     */
+    public String getSourceModuleVersion() {
+        calculateCaller();
+        return sourceModuleVersion;
+    }
+
+    /**
+     * Set the source module version of this record.
+     *
+     * @param sourceModuleVersion the source module version
+     */
+    public void setSourceModuleVersion(final String sourceModuleVersion) {
+        calculateCaller = false;
+        this.sourceModuleVersion = sourceModuleVersion;
+    }
+
     /**
      * Get the fully formatted log record, with resources resolved and parameters applied.
      *
@@ -469,6 +528,60 @@ public class ExtLogRecord extends LogRecord {
         this.threadName = threadName;
     }
 
+    /**
+     * Get the host name of the record, if known.
+     *
+     * @return the host name of the record, if known
+     */
+    public String getHostName() {
+        return hostName;
+    }
+
+    /**
+     * Set the host name of the record.
+     *
+     * @param hostName the host name of the record
+     */
+    public void setHostName(final String hostName) {
+        this.hostName = hostName;
+    }
+
+    /**
+     * Get the process name of the record, if known.
+     *
+     * @return the process name of the record, if known
+     */
+    public String getProcessName() {
+        return processName;
+    }
+
+    /**
+     * Set the process name of the record.
+     *
+     * @param processName the process name of the record
+     */
+    public void setProcessName(final String processName) {
+        this.processName = processName;
+    }
+
+    /**
+     * Get the process ID of the record, if known.
+     *
+     * @return the process ID of the record, or -1 if not known
+     */
+    public long getProcessId() {
+        return processId;
+    }
+
+    /**
+     * Set the process ID of the record.
+     *
+     * @param processId the process ID of the record
+     */
+    public void setProcessId(final long processId) {
+        this.processId = processId;
+    }
+
     /**
      * Set the raw message.  Any cached formatted message is discarded.  The parameter format is set to be
      * {@link java.text.MessageFormat}-style.
